pub struct ComboBox { /* private fields */ }Expand description
A drop-down selection menu with a descriptive label.
egui::ComboBox::from_label("Select one!")
.selected_text(format!("{:?}", selected))
.show_ui(ui, |ui| {
ui.selectable_value(&mut selected, Enum::First, "First");
ui.selectable_value(&mut selected, Enum::Second, "Second");
ui.selectable_value(&mut selected, Enum::Third, "Third");
}
);Implementations
Sourceimpl ComboBox
impl ComboBox
Sourcepub fn new(id_source: impl Hash, label: impl Into<WidgetText>) -> ComboBox
pub fn new(id_source: impl Hash, label: impl Into<WidgetText>) -> ComboBox
Create new ComboBox with id and label
Sourcepub fn from_label(label: impl Into<WidgetText>) -> ComboBox
pub fn from_label(label: impl Into<WidgetText>) -> ComboBox
Label shown next to the combo box
Sourcepub fn from_id_source(id_source: impl Hash) -> ComboBox
pub fn from_id_source(id_source: impl Hash) -> ComboBox
Without label.
Sourcepub fn selected_text(self, selected_text: impl Into<WidgetText>) -> ComboBox
pub fn selected_text(self, selected_text: impl Into<WidgetText>) -> ComboBox
What we show as the currently selected value
Sourcepub fn icon(
self,
icon_fn: impl FnOnce(&Ui, Rect, &WidgetVisuals, bool, AboveOrBelow) + 'static,
) -> ComboBox
pub fn icon( self, icon_fn: impl FnOnce(&Ui, Rect, &WidgetVisuals, bool, AboveOrBelow) + 'static, ) -> ComboBox
Use the provided function to render a different ComboBox icon.
Defaults to a triangle that expands when the cursor is hovering over the ComboBox.
For example:
pub fn filled_triangle(
ui: &egui::Ui,
rect: egui::Rect,
visuals: &egui::style::WidgetVisuals,
_is_open: bool,
_above_or_below: egui::AboveOrBelow,
) {
let rect = egui::Rect::from_center_size(
rect.center(),
egui::vec2(rect.width() * 0.6, rect.height() * 0.4),
);
ui.painter().add(egui::Shape::convex_polygon(
vec![rect.left_top(), rect.right_top(), rect.center_bottom()],
visuals.fg_stroke.color,
visuals.fg_stroke,
));
}
egui::ComboBox::from_id_source("my-combobox")
.selected_text(text)
.icon(filled_triangle)
.show_ui(ui, |_ui| {});Sourcepub fn wrap(self, wrap: bool) -> ComboBox
pub fn wrap(self, wrap: bool) -> ComboBox
Controls whether text wrap is used for the selected text
Sourcepub fn show_ui<R>(
self,
ui: &mut Ui,
menu_contents: impl FnOnce(&mut Ui) -> R,
) -> InnerResponse<Option<R>>
pub fn show_ui<R>( self, ui: &mut Ui, menu_contents: impl FnOnce(&mut Ui) -> R, ) -> InnerResponse<Option<R>>
Show the combo box, with the given ui code for the menu contents.
Returns InnerResponse { inner: None } if the combo box is closed.
Sourcepub fn show_index<Text>(
self,
ui: &mut Ui,
selected: &mut usize,
len: usize,
get: impl Fn(usize) -> Text,
) -> Responsewhere
Text: Into<WidgetText>,
pub fn show_index<Text>(
self,
ui: &mut Ui,
selected: &mut usize,
len: usize,
get: impl Fn(usize) -> Text,
) -> Responsewhere
Text: Into<WidgetText>,
Show a list of items with the given selected index.
let alternatives = ["a", "b", "c", "d"];
let mut selected = 2;
egui::ComboBox::from_label("Select one!").show_index(
ui,
&mut selected,
alternatives.len(),
|i| alternatives[i]
);Auto Trait Implementations
impl Freeze for ComboBox
impl !RefUnwindSafe for ComboBox
impl !Send for ComboBox
impl !Sync for ComboBox
impl Unpin for ComboBox
impl !UnwindSafe for ComboBox