pub struct EncodingError { /* private fields */ }Expand description
An error was encountered while encoding an image.
This is used as an opaque representation for the ImageError::Encoding variant. See its
documentation for more information.
Implementations
Sourceimpl EncodingError
impl EncodingError
Sourcepub fn new(
format: ImageFormatHint,
err: impl Into<Box<dyn Error + Sync + Send>>,
) -> EncodingError
pub fn new( format: ImageFormatHint, err: impl Into<Box<dyn Error + Sync + Send>>, ) -> EncodingError
Create an EncodingError that stems from an arbitrary error of an underlying encoder.
Sourcepub fn from_format_hint(format: ImageFormatHint) -> EncodingError
pub fn from_format_hint(format: ImageFormatHint) -> EncodingError
Create an EncodingError for an image format.
The error will not contain any further information but is very easy to create.
Sourcepub fn format_hint(&self) -> ImageFormatHint
pub fn format_hint(&self) -> ImageFormatHint
Return the image format associated with this error.