pub struct LimitError { /* private fields */ }Expand description
Completing the operation would have required more resources than allowed.
This is used as an opaque representation for the ImageError::Limits variant. See its
documentation for more information.
Implementations
Sourceimpl LimitError
impl LimitError
Sourcepub fn from_kind(kind: LimitErrorKind) -> LimitError
pub fn from_kind(kind: LimitErrorKind) -> LimitError
Construct a generic LimitError directly from a corresponding kind.
Sourcepub fn kind(&self) -> LimitErrorKind
pub fn kind(&self) -> LimitErrorKind
Returns the corresponding LimitErrorKind of the error.